==> apache_superset-4.1.3-source.tar.gz: apache_superset-4.1.3rc2/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

## Change Log

- [1.4.1](./CHANGELOG/1.4.1.md)
- [1.4.2](./CHANGELOG/1.4.2.md)
- [1.5.0](./CHANGELOG/1.5.0.md)
- [1.5.1](./CHANGELOG/1.5.1.md)
- [1.5.2](./CHANGELOG/1.5.2.md)
- [1.5.3](./CHANGELOG/1.5.3.md)
- [2.0.0](./CHANGELOG/2.0.0.md)
- [2.0.1](./CHANGELOG/2.0.1.md)
- [2.1.0](./CHANGELOG/2.1.0.md)
- [2.1.1](./CHANGELOG/2.1.1.md)
- [2.1.2](./CHANGELOG/2.1.2.md)
- [2.1.3](./CHANGELOG/2.1.3.md)
- [3.0.0](./CHANGELOG/3.0.0.md)
- [3.0.1](./CHANGELOG/3.0.1.md)
- [3.0.2](./CHANGELOG/3.0.2.md)
- [3.0.3](./CHANGELOG/3.0.3.md)
- [3.0.4](./CHANGELOG/3.0.4.md)
- [3.1.0](./CHANGELOG/3.1.0.md)
- [3.1.1](./CHANGELOG/3.1.1.md)
- [3.1.2](./CHANGELOG/3.1.2.md)
- [3.1.3](./CHANGELOG/3.1.3.md)
- [4.0.0](./CHANGELOG/4.0.0.md)
- [4.0.1](./CHANGELOG/4.0.1.md)
- [4.0.2](./CHANGELOG/4.0.2.md)
- [4.1.0](./CHANGELOG/4.1.0.md)

==> apache_superset-4.1.4-source.tar.gz: apache_superset-4.1.4rc1/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

## Change Log

- [1.4.1](./CHANGELOG/1.4.1.md)
- [1.4.2](./CHANGELOG/1.4.2.md)
- [1.5.0](./CHANGELOG/1.5.0.md)
- [1.5.1](./CHANGELOG/1.5.1.md)
- [1.5.2](./CHANGELOG/1.5.2.md)
- [1.5.3](./CHANGELOG/1.5.3.md)
- [2.0.0](./CHANGELOG/2.0.0.md)
- [2.0.1](./CHANGELOG/2.0.1.md)
- [2.1.0](./CHANGELOG/2.1.0.md)
- [2.1.1](./CHANGELOG/2.1.1.md)
- [2.1.2](./CHANGELOG/2.1.2.md)
- [2.1.3](./CHANGELOG/2.1.3.md)
- [3.0.0](./CHANGELOG/3.0.0.md)
- [3.0.1](./CHANGELOG/3.0.1.md)
- [3.0.2](./CHANGELOG/3.0.2.md)
- [3.0.3](./CHANGELOG/3.0.3.md)
- [3.0.4](./CHANGELOG/3.0.4.md)
- [3.1.0](./CHANGELOG/3.1.0.md)
- [3.1.1](./CHANGELOG/3.1.1.md)
- [3.1.2](./CHANGELOG/3.1.2.md)
- [3.1.3](./CHANGELOG/3.1.3.md)
- [4.0.0](./CHANGELOG/4.0.0.md)
- [4.0.1](./CHANGELOG/4.0.1.md)
- [4.0.2](./CHANGELOG/4.0.2.md)
- [4.1.0](./CHANGELOG/4.1.0.md)
- [4.1.1](./CHANGELOG/4.1.1.md)
- [4.1.2](./CHANGELOG/4.1.2.md)
- [4.1.3](./CHANGELOG/4.1.3.md)
- [4.1.4](./CHANGELOG/4.1.4.md)
